
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    print qq{1..0 # SKIP these tests are for testing by the author\n};
    exit
  }
}

use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.19

use Test::More 0.88;
use Test::EOL;

my @files = (
    'bin/s3cl',
    'lib/Net/Amazon/S3.pm',
    'lib/Net/Amazon/S3/ACL.pod',
    'lib/Net/Amazon/S3/ACL/Canned.pm',
    'lib/Net/Amazon/S3/ACL/Grantee.pm',
    'lib/Net/Amazon/S3/ACL/Grantee/Email.pm',
    'lib/Net/Amazon/S3/ACL/Grantee/Group.pm',
    'lib/Net/Amazon/S3/ACL/Grantee/User.pm',
    'lib/Net/Amazon/S3/ACL/Set.pm',
    'lib/Net/Amazon/S3/Authorization.pm',
    'lib/Net/Amazon/S3/Authorization/Basic.pm',
    'lib/Net/Amazon/S3/Authorization/IAM.pm',
    'lib/Net/Amazon/S3/Bucket.pm',
    'lib/Net/Amazon/S3/Client.pm',
    'lib/Net/Amazon/S3/Client/Bucket.pm',
    'lib/Net/Amazon/S3/Client/Object.pm',
    'lib/Net/Amazon/S3/Constants.pm',
    'lib/Net/Amazon/S3/Constraint/ACL/Canned.pm',
    'lib/Net/Amazon/S3/Error/Handler.pm',
    'lib/Net/Amazon/S3/Error/Handler/Confess.pm',
    'lib/Net/Amazon/S3/Error/Handler/Legacy.pm',
    'lib/Net/Amazon/S3/Error/Handler/Status.pm',
    'lib/Net/Amazon/S3/Error/Handler/X.pm',
    'lib/Net/Amazon/S3/Features.pod',
    'lib/Net/Amazon/S3/HTTPRequest.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Acl/Fetch.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Acl/Fetch/Request.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Acl/Fetch/Response.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Acl/Set.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Acl/Set/Request.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Acl/Set/Response.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Create.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Create/Request.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Create/Response.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Delete.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Delete/Request.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Delete/Response.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Location.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Location/Request.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Location/Response.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Tags/Add.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Tags/Add/Request.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Tags/Add/Response.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Tags/Delete.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Tags/Delete/Request.pm',
    'lib/Net/Amazon/S3/Operation/Bucket/Tags/Delete/Response.pm',
    'lib/Net/Amazon/S3/Operation/Buckets/List.pm',
    'lib/Net/Amazon/S3/Operation/Buckets/List/Request.pm',
    'lib/Net/Amazon/S3/Operation/Buckets/List/Response.pm',
    'lib/Net/Amazon/S3/Operation/Object/Acl/Fetch.pm',
    'lib/Net/Amazon/S3/Operation/Object/Acl/Fetch/Request.pm',
    'lib/Net/Amazon/S3/Operation/Object/Acl/Fetch/Response.pm',
    'lib/Net/Amazon/S3/Operation/Object/Acl/Set.pm',
    'lib/Net/Amazon/S3/Operation/Object/Acl/Set/Request.pm',
    'lib/Net/Amazon/S3/Operation/Object/Acl/Set/Response.pm',
    'lib/Net/Amazon/S3/Operation/Object/Add.pm',
    'lib/Net/Amazon/S3/Operation/Object/Add/Request.pm',
    'lib/Net/Amazon/S3/Operation/Object/Add/Response.pm',
    'lib/Net/Amazon/S3/Operation/Object/Delete.pm',
    'lib/Net/Amazon/S3/Operation/Object/Delete/Request.pm',
    'lib/Net/Amazon/S3/Operation/Object/Delete/Response.pm',
    'lib/Net/Amazon/S3/Operation/Object/Fetch.pm',
    'lib/Net/Amazon/S3/Operation/Object/Fetch/Request.pm',
    'lib/Net/Amazon/S3/Operation/Object/Fetch/Response.pm',
    'lib/Net/Amazon/S3/Operation/Object/Head.pm',
    'lib/Net/Amazon/S3/Operation/Object/Head/Request.pm',
    'lib/Net/Amazon/S3/Operation/Object/Head/Response.pm',
    'lib/Net/Amazon/S3/Operation/Object/Restore.pm',
    'lib/Net/Amazon/S3/Operation/Object/Restore/Request.pm',
    'lib/Net/Amazon/S3/Operation/Object/Restore/Response.pm',
    'lib/Net/Amazon/S3/Operation/Object/Tags/Add.pm',
    'lib/Net/Amazon/S3/Operation/Object/Tags/Add/Request.pm',
    'lib/Net/Amazon/S3/Operation/Object/Tags/Add/Response.pm',
    'lib/Net/Amazon/S3/Operation/Object/Tags/Delete.pm',
    'lib/Net/Amazon/S3/Operation/Object/Tags/Delete/Request.pm',
    'lib/Net/Amazon/S3/Operation/Object/Tags/Delete/Response.pm',
    'lib/Net/Amazon/S3/Operation/Object/Upload/Abort.pm',
    'lib/Net/Amazon/S3/Operation/Object/Upload/Abort/Request.pm',
    'lib/Net/Amazon/S3/Operation/Object/Upload/Abort/Response.pm',
    'lib/Net/Amazon/S3/Operation/Object/Upload/Complete.pm',
    'lib/Net/Amazon/S3/Operation/Object/Upload/Complete/Request.pm',
    'lib/Net/Amazon/S3/Operation/Object/Upload/Complete/Response.pm',
    'lib/Net/Amazon/S3/Operation/Object/Upload/Create.pm',
    'lib/Net/Amazon/S3/Operation/Object/Upload/Create/Request.pm',
    'lib/Net/Amazon/S3/Operation/Object/Upload/Create/Response.pm',
    'lib/Net/Amazon/S3/Operation/Object/Upload/Part.pm',
    'lib/Net/Amazon/S3/Operation/Object/Upload/Part/Request.pm',
    'lib/Net/Amazon/S3/Operation/Object/Upload/Part/Response.pm',
    'lib/Net/Amazon/S3/Operation/Object/Upload/Parts.pm',
    'lib/Net/Amazon/S3/Operation/Object/Upload/Parts/Request.pm',
    'lib/Net/Amazon/S3/Operation/Object/Upload/Parts/Response.pm',
    'lib/Net/Amazon/S3/Operation/Objects/Delete.pm',
    'lib/Net/Amazon/S3/Operation/Objects/Delete/Request.pm',
    'lib/Net/Amazon/S3/Operation/Objects/Delete/Response.pm',
    'lib/Net/Amazon/S3/Operation/Objects/List.pm',
    'lib/Net/Amazon/S3/Operation/Objects/List/Request.pm',
    'lib/Net/Amazon/S3/Operation/Objects/List/Response.pm',
    'lib/Net/Amazon/S3/Request.pm',
    'lib/Net/Amazon/S3/Request/Bucket.pm',
    'lib/Net/Amazon/S3/Request/Object.pm',
    'lib/Net/Amazon/S3/Request/Role/HTTP/Header.pm',
    'lib/Net/Amazon/S3/Request/Role/HTTP/Header/ACL.pm',
    'lib/Net/Amazon/S3/Request/Role/HTTP/Header/Content_length.pm',
    'lib/Net/Amazon/S3/Request/Role/HTTP/Header/Content_md5.pm',
    'lib/Net/Amazon/S3/Request/Role/HTTP/Header/Content_type.pm',
    'lib/Net/Amazon/S3/Request/Role/HTTP/Header/Copy_source.pm',
    'lib/Net/Amazon/S3/Request/Role/HTTP/Header/Encryption.pm',
    'lib/Net/Amazon/S3/Request/Role/HTTP/Method.pm',
    'lib/Net/Amazon/S3/Request/Role/HTTP/Method/DELETE.pm',
    'lib/Net/Amazon/S3/Request/Role/HTTP/Method/GET.pm',
    'lib/Net/Amazon/S3/Request/Role/HTTP/Method/HEAD.pm',
    'lib/Net/Amazon/S3/Request/Role/HTTP/Method/POST.pm',
    'lib/Net/Amazon/S3/Request/Role/HTTP/Method/PUT.pm',
    'lib/Net/Amazon/S3/Request/Role/Query/Action.pm',
    'lib/Net/Amazon/S3/Request/Role/Query/Action/Acl.pm',
    'lib/Net/Amazon/S3/Request/Role/Query/Action/Delete.pm',
    'lib/Net/Amazon/S3/Request/Role/Query/Action/Location.pm',
    'lib/Net/Amazon/S3/Request/Role/Query/Action/Restore.pm',
    'lib/Net/Amazon/S3/Request/Role/Query/Action/Tagging.pm',
    'lib/Net/Amazon/S3/Request/Role/Query/Action/Uploads.pm',
    'lib/Net/Amazon/S3/Request/Role/Query/Param.pm',
    'lib/Net/Amazon/S3/Request/Role/Query/Param/Delimiter.pm',
    'lib/Net/Amazon/S3/Request/Role/Query/Param/Marker.pm',
    'lib/Net/Amazon/S3/Request/Role/Query/Param/Max_keys.pm',
    'lib/Net/Amazon/S3/Request/Role/Query/Param/Part_number.pm',
    'lib/Net/Amazon/S3/Request/Role/Query/Param/Prefix.pm',
    'lib/Net/Amazon/S3/Request/Role/Query/Param/Upload_id.pm',
    'lib/Net/Amazon/S3/Request/Role/Query/Param/Version_id.pm',
    'lib/Net/Amazon/S3/Request/Role/Tags/Add.pm',
    'lib/Net/Amazon/S3/Request/Role/XML/Content.pm',
    'lib/Net/Amazon/S3/Request/Service.pm',
    'lib/Net/Amazon/S3/Response.pm',
    'lib/Net/Amazon/S3/Role/ACL.pm',
    'lib/Net/Amazon/S3/Role/Bucket.pm',
    'lib/Net/Amazon/S3/Signature.pm',
    'lib/Net/Amazon/S3/Signature/V2.pm',
    'lib/Net/Amazon/S3/Signature/V4.pm',
    'lib/Net/Amazon/S3/Signature/V4Implementation.pm',
    'lib/Net/Amazon/S3/Utils.pm',
    'lib/Net/Amazon/S3/Vendor.pm',
    'lib/Net/Amazon/S3/Vendor/Amazon.pm',
    'lib/Net/Amazon/S3/Vendor/Generic.pm',
    'lib/Net/Amazon/S3/X.pm',
    'lib/Shared/Examples/Net/Amazon/S3.pm',
    'lib/Shared/Examples/Net/Amazon/S3/API.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Client.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/error/access_denied.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/error/bucket_already_exists.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/error/bucket_not_empty.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/error/http_bad_request.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/error/invalid_bucket_name.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/error/invalid_object_state.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/error/no_such_bucket.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/error/no_such_key.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/request/bucket_create_ca_central_1.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/response/acl.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/response/bucket_objects_delete_quiet_without_errors.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/response/bucket_objects_list_v1.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/response/bucket_objects_list_v1_google_cloud_storage.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/response/bucket_objects_list_v1_with_delimiter.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/response/bucket_objects_list_v1_with_filter.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/response/bucket_objects_list_v1_with_filter_truncated.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/response/bucket_objects_list_v1_with_prefix_and_delimiter.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/response/create_multipart_upload_with_success.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/response/http_ok_empty.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/response/service_list_buckets_with_owner_displayname.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Fixture/response/service_list_buckets_without_owner_displayname.pm',
    'lib/Shared/Examples/Net/Amazon/S3/Request.pm',
    't/01api.t',
    't/02client.t',
    't/03token.t',
    't/acl-set.t',
    't/api-bucket-acl-get.t',
    't/api-bucket-acl-set.t',
    't/api-bucket-create.t',
    't/api-bucket-delete.t',
    't/api-bucket-objects-delete.t',
    't/api-bucket-objects-list.t',
    't/api-bucket-tags-add.t',
    't/api-bucket-tags-delete.t',
    't/api-build-bucket.t',
    't/api-construct.t',
    't/api-object-acl-get.t',
    't/api-object-acl-set.t',
    't/api-object-create.t',
    't/api-object-delete.t',
    't/api-object-fetch.t',
    't/api-object-head.t',
    't/api-object-tags-add.t',
    't/api-object-tags-delete.t',
    't/api-service-buckets-list.t',
    't/author-eol.t',
    't/client-bucket-acl-get.t',
    't/client-bucket-acl-set.t',
    't/client-bucket-create.t',
    't/client-bucket-delete.t',
    't/client-bucket-objects-delete.t',
    't/client-bucket-objects-list.t',
    't/client-bucket-tags-add.t',
    't/client-bucket-tags-delete.t',
    't/client-construct.t',
    't/client-object-acl-set.t',
    't/client-object-create.t',
    't/client-object-delete.t',
    't/client-object-fetch.t',
    't/client-object-head.t',
    't/client-object-tags-add.t',
    't/client-object-tags-delete.t',
    't/client-service-buckets-list.t',
    't/data/s3-operation-object-add.txt',
    't/error-handler-x.t',
    't/issue-39-content-length-0.t',
    't/issue-88-non-standard-service-port.t',
    't/query-string-authentication-uri.t',
    't/request.t',
    't/response.t',
    't/s3-operation-bucket-acl-fetch.t',
    't/s3-operation-bucket-acl-set.t',
    't/s3-operation-bucket-create.t',
    't/s3-operation-bucket-delete.t',
    't/s3-operation-bucket-location.t',
    't/s3-operation-bucket-tags-add.t',
    't/s3-operation-bucket-tags-delete.t',
    't/s3-operation-buckets-list.t',
    't/s3-operation-object-acl-fetch.t',
    't/s3-operation-object-acl-set.t',
    't/s3-operation-object-add.t',
    't/s3-operation-object-copy.t',
    't/s3-operation-object-delete.t',
    't/s3-operation-object-fetch.t',
    't/s3-operation-object-head.t',
    't/s3-operation-object-restore.t',
    't/s3-operation-object-tags-add.t',
    't/s3-operation-object-tags-delete.t',
    't/s3-operation-object-upload-abort.t',
    't/s3-operation-object-upload-complete.t',
    't/s3-operation-object-upload-create.t',
    't/s3-operation-object-upload-part.t',
    't/s3-operation-objects-delete.t',
    't/s3-operation-objects-list.t',
    't/s3-request-bucket-acl-fetch.t',
    't/s3-request-bucket-acl-set.t',
    't/s3-request-bucket-create.t',
    't/s3-request-bucket-delete.t',
    't/s3-request-bucket-location.t',
    't/s3-request-bucket-objects-delete.t',
    't/s3-request-bucket-objects-list.t',
    't/s3-request-bucket-tags-add.t',
    't/s3-request-bucket-tags-delete.t',
    't/s3-request-object-acl-fetch.t',
    't/s3-request-object-acl-set.t',
    't/s3-request-object-add.t',
    't/s3-request-object-delete.t',
    't/s3-request-object-fetch.t',
    't/s3-request-object-restore.t',
    't/s3-request-object-tags-add.t',
    't/s3-request-object-tags-delete.t',
    't/s3-request-object-upload-abort.t',
    't/s3-request-object-upload-complete.t',
    't/s3-request-object-upload-create.t',
    't/s3-request-object-upload-part.t',
    't/s3-request-object-upload-parts.t',
    't/s3-request-service-buckets-list.t',
    't/s3-response-object-upload-create.t',
    't/s3-response-service-buckets-list.t',
    't/signature-v4-with-security-token.t',
    't/test-helper-common.pl',
    't/test-helper-errors.pl',
    't/test-helper-operation.pl',
    't/test-helper-s3-api-error-confess.pl',
    't/test-helper-s3-api-error-status.pl',
    't/test-helper-s3-api.pl',
    't/test-helper-s3-client.pl',
    't/test-helper-s3-request.pl',
    't/test-helper-s3-response.pl',
    't/test-helper-tags.pl',
    't/utils-parse-arguments.t',
    't/vendor-amazon.t',
    't/vendor-generic.t',
    't/vendor-info.t'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
